@@ -7,13 +7,13 @@ use strict;
 
 package XML::Compile::WSS::SecToken;
 use vars '$VERSION';
-$VERSION = '0.90';
+$VERSION = '0.91';
 
 
 use Log::Report 'xml-compile-wss-sig';
 
 use XML::Compile::WSS::Util   qw/XTP10_X509v3 WSU_10 WSM10_BASE64/;
-use MIME::Base64              qw/decode_base64/;
+use MIME::Base64              qw/decode_base64 encode_base64/;
 
 
 sub new(@)
